# PokerNow

PokerNow API Client

## Installation

```pip install PokerNow```

## Usage

```python
import PokerNow

PokerNow.main()
```

## License

Â© 2021 Zehm

This repository is licensed under the MIT license. See LICENSE for details.
